@@ -1,4 +1,4 @@
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, model_validator
 from typing import Dict, Any
 
 from letschatty.models.utils.types.identifier import StrObjectId
@@ -36,11 +36,23 @@ class QualityTestInteractionCallbackEvent(LambdaAiEvent):
     data: ExpectedOutputIncomingMessage
     callback_metadata: InteractionCallbackMetadata
 
+    @model_validator(mode="before")
+    def validate_data(cls, data):
+        if isinstance(data, dict) and "data" in data and "chain_of_thought" in data["data"]:
+            data["data"]["chain_of_thought"]["chatty_ai_agent_id"] = "000000000000000000000000"
+        return data
+
 class SmartTaggingCallbackEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.SMART_TAGGING_CALLBACK
     data: ExpectedOutputSmartTag
     callback_metadata: SmartTaggingCallbackMetadata
 
+    @model_validator(mode="before")
+    def validate_data(cls, data):
+        if isinstance(data, dict) and "data" in data and "callback_metadata" in data and "chain_of_thought" in data["data"]:
+            data["data"]["chain_of_thought"]["chatty_ai_agent_id"] = data["callback_metadata"]["ai_agent_id"]
+        return data
+
 class ChatData(BaseModel):
     chat_id: StrObjectId
     company_id: StrObjectId
@@ -73,3 +85,7 @@ class AllQualityTestEvent(LambdaAiEvent):
 class SmartTaggingEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.SMART_TAGGING
     data: ChatData
+
+class SmartTaggingPromptEvent(LambdaAiEvent):
+    type: InvokationType = InvokationType.SMART_TAGGING_PROMPT
+    data: ChatData
